pub fn find_root(config: &AuditConfig) -> PathBufExpand description
Find the project root by walking up from CWD.
Strategy depends on config:
- Pass 1: Check
config.root_markersin order - Pass 2: Check for
.gitdirectory - Pass 3: Fall back to CWD
pub fn find_root(config: &AuditConfig) -> PathBufFind the project root by walking up from CWD.
Strategy depends on config:
config.root_markers in order.git directory