pub fn is_agent_file(rel: &str, config: &AuditConfig) -> boolExpand description
Check if a file path refers to an agent instruction file.
pub fn is_agent_file(rel: &str, config: &AuditConfig) -> boolCheck if a file path refers to an agent instruction file.